@@ -4,4 +4,4 @@ from django import forms
 
 
 class ExcelUploaderForm(forms.Form):
-    file = forms.FileField(label='Select Excel File')
+    file = forms.FileField(label="Select Excel File")
